==> huaweicloudsdkvpc-3.1.134-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/delete_port_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeletePortTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'port_id': 'str',
        'tag_key': 'str'
    }

    attribute_map = {
        'port_id': 'port_id',
        'tag_key': 'tag_key'
    }

    def __init__(self, port_id=None, tag_key=None):
        """DeletePortTagRequest

        The model defined in huaweicloud sdk

        :param port_id: 功能说明：端口唯一标识 取值范围：合法UUID 约束：ID对应的端口必须存在
        :type port_id: str
        :param tag_key: 功能说明：标签键
        :type tag_key: str
        """
        
        

        self._port_id = None
        self._tag_key = None
        self.discriminator = None

        self.port_id = port_id
        self.tag_key = tag_key

    @property
    def port_id(self):
        """Gets the port_id of this DeletePortTagRequest.

        功能说明：端口唯一标识 取值范围：合法UUID 约束：ID对应的端口必须存在

        :return: The port_id of this DeletePortTagRequest.
        :rtype: str
        """
        return self._port_id

    @port_id.setter
    def port_id(self, port_id):
        """Sets the port_id of this DeletePortTagRequest.

        功能说明：端口唯一标识 取值范围：合法UUID 约束：ID对应的端口必须存在

        :param port_id: The port_id of this DeletePortTagRequest.
        :type port_id: str
        """
        self._port_id = port_id

    @property
    def tag_key(self):
        """Gets the tag_key of this DeletePortTagRequest.

        功能说明：标签键

        :return: The tag_key of this DeletePortTagRequest.
        :rtype: str
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        """Sets the tag_key of this DeletePortTagRequest.

        功能说明：标签键

        :param tag_key: The tag_key of this DeletePortTagRequest.
        :type tag_key: str
        """
        self._tag_key = tag_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeletePortTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkvpc-3.1.150-py2.py3-none-any.whl: huaweicloudsdkvpc/v3/model/delete_port_tag_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DeletePortTagRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'port_id': 'str',
        'tag_key': 'str'
    }

    attribute_map = {
        'port_id': 'port_id',
        'tag_key': 'tag_key'
    }

    def __init__(self, port_id=None, tag_key=None):
        r"""DeletePortTagRequest

        The model defined in huaweicloud sdk

        :param port_id: 功能说明：端口唯一标识 取值范围：合法UUID 约束：ID对应的端口必须存在
        :type port_id: str
        :param tag_key: 功能说明：标签键
        :type tag_key: str
        """
        
        

        self._port_id = None
        self._tag_key = None
        self.discriminator = None

        self.port_id = port_id
        self.tag_key = tag_key

    @property
    def port_id(self):
        r"""Gets the port_id of this DeletePortTagRequest.

        功能说明：端口唯一标识 取值范围：合法UUID 约束：ID对应的端口必须存在

        :return: The port_id of this DeletePortTagRequest.
        :rtype: str
        """
        return self._port_id

    @port_id.setter
    def port_id(self, port_id):
        r"""Sets the port_id of this DeletePortTagRequest.

        功能说明：端口唯一标识 取值范围：合法UUID 约束：ID对应的端口必须存在

        :param port_id: The port_id of this DeletePortTagRequest.
        :type port_id: str
        """
        self._port_id = port_id

    @property
    def tag_key(self):
        r"""Gets the tag_key of this DeletePortTagRequest.

        功能说明：标签键

        :return: The tag_key of this DeletePortTagRequest.
        :rtype: str
        """
        return self._tag_key

    @tag_key.setter
    def tag_key(self, tag_key):
        r"""Sets the tag_key of this DeletePortTagRequest.

        功能说明：标签键

        :param tag_key: The tag_key of this DeletePortTagRequest.
        :type tag_key: str
        """
        self._tag_key = tag_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeletePortTagRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
